# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class SignUpPendingUserResolveAPIInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'password': 'str',
        'redeem_code': 'str',
        'token': 'str',
        'username': 'str'
    }

    attribute_map = {
        'password': 'password',
        'redeem_code': 'redeem_code',
        'token': 'token',
        'username': 'username'
    }

    def __init__(self, password=None, redeem_code=None, token=None, username=None, local_vars_configuration=None):  # noqa: E501
        """SignUpPendingUserResolveAPIInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._password = None
        self._redeem_code = None
        self._token = None
        self._username = None
        self.discriminator = None

        self.password = password
        if redeem_code is not None:
            self.redeem_code = redeem_code
        self.token = token
        self.username = username

    @property
    def password(self):
        """Gets the password of this SignUpPendingUserResolveAPIInput.  # noqa: E501


        :return: The password of this SignUpPendingUserResolveAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this SignUpPendingUserResolveAPIInput.


        :param password: The password of this SignUpPendingUserResolveAPIInput.  # noqa: E501
        :type password: str
        """
        if self.local_vars_configuration.client_side_validation and password is None:  # noqa: E501
            raise ValueError("Invalid value for `password`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                password is not None and len(password) > 255):
            raise ValueError("Invalid value for `password`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                password is not None and len(password) < 8):
            raise ValueError("Invalid value for `password`, length must be greater than or equal to `8`")  # noqa: E501

        self._password = password

    @property
    def redeem_code(self):
        """Gets the redeem_code of this SignUpPendingUserResolveAPIInput.  # noqa: E501


        :return: The redeem_code of this SignUpPendingUserResolveAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._redeem_code

    @redeem_code.setter
    def redeem_code(self, redeem_code):
        """Sets the redeem_code of this SignUpPendingUserResolveAPIInput.


        :param redeem_code: The redeem_code of this SignUpPendingUserResolveAPIInput.  # noqa: E501
        :type redeem_code: str
        """

        self._redeem_code = redeem_code

    @property
    def token(self):
        """Gets the token of this SignUpPendingUserResolveAPIInput.  # noqa: E501


        :return: The token of this SignUpPendingUserResolveAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this SignUpPendingUserResolveAPIInput.


        :param token: The token of this SignUpPendingUserResolveAPIInput.  # noqa: E501
        :type token: str
        """
        if self.local_vars_configuration.client_side_validation and token is None:  # noqa: E501
            raise ValueError("Invalid value for `token`, must not be `None`")  # noqa: E501

        self._token = token

    @property
    def username(self):
        """Gets the username of this SignUpPendingUserResolveAPIInput.  # noqa: E501


        :return: The username of this SignUpPendingUserResolveAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this SignUpPendingUserResolveAPIInput.


        :param username: The username of this SignUpPendingUserResolveAPIInput.  # noqa: E501
        :type username: str
        """
        if self.local_vars_configuration.client_side_validation and username is None:  # noqa: E501
            raise ValueError("Invalid value for `username`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                username is not None and len(username) > 255):
            raise ValueError("Invalid value for `username`, length must be less than or equal to `255`")  # noqa: E501

        self._username = username

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SignUpPendingUserResolveAPIInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SignUpPendingUserResolveAPIInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmPipelineSpecEdges(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'executions': 'list[OrmPipelineExecution]',
        'pipeline': 'OrmPipeline',
        'pipeline_step_external_services': 'list[OrmPipelineStepExternalService]',
        'pipeline_step_ifs': 'list[OrmPipelineStepIf]',
        'pipeline_step_jupyter_visualizations': 'list[OrmPipelineStepJupyterVisualization]',
        'pipeline_step_manual_inputs': 'list[OrmPipelineStepManualInput]',
        'pipeline_step_manual_judgments': 'list[OrmPipelineStepManualJudgment]',
        'pipeline_step_runs': 'list[OrmPipelineStepRun]',
        'pipeline_step_specs': 'list[OrmPipelineStepSpec]'
    }

    attribute_map = {
        'executions': 'executions',
        'pipeline': 'pipeline',
        'pipeline_step_external_services': 'pipeline_step_external_services',
        'pipeline_step_ifs': 'pipeline_step_ifs',
        'pipeline_step_jupyter_visualizations': 'pipeline_step_jupyter_visualizations',
        'pipeline_step_manual_inputs': 'pipeline_step_manual_inputs',
        'pipeline_step_manual_judgments': 'pipeline_step_manual_judgments',
        'pipeline_step_runs': 'pipeline_step_runs',
        'pipeline_step_specs': 'pipeline_step_specs'
    }

    def __init__(self, executions=None, pipeline=None, pipeline_step_external_services=None, pipeline_step_ifs=None, pipeline_step_jupyter_visualizations=None, pipeline_step_manual_inputs=None, pipeline_step_manual_judgments=None, pipeline_step_runs=None, pipeline_step_specs=None, local_vars_configuration=None):  # noqa: E501
        """OrmPipelineSpecEdges - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._executions = None
        self._pipeline = None
        self._pipeline_step_external_services = None
        self._pipeline_step_ifs = None
        self._pipeline_step_jupyter_visualizations = None
        self._pipeline_step_manual_inputs = None
        self._pipeline_step_manual_judgments = None
        self._pipeline_step_runs = None
        self._pipeline_step_specs = None
        self.discriminator = None

        if executions is not None:
            self.executions = executions
        if pipeline is not None:
            self.pipeline = pipeline
        if pipeline_step_external_services is not None:
            self.pipeline_step_external_services = pipeline_step_external_services
        if pipeline_step_ifs is not None:
            self.pipeline_step_ifs = pipeline_step_ifs
        if pipeline_step_jupyter_visualizations is not None:
            self.pipeline_step_jupyter_visualizations = pipeline_step_jupyter_visualizations
        if pipeline_step_manual_inputs is not None:
            self.pipeline_step_manual_inputs = pipeline_step_manual_inputs
        if pipeline_step_manual_judgments is not None:
            self.pipeline_step_manual_judgments = pipeline_step_manual_judgments
        if pipeline_step_runs is not None:
            self.pipeline_step_runs = pipeline_step_runs
        if pipeline_step_specs is not None:
            self.pipeline_step_specs = pipeline_step_specs

    @property
    def executions(self):
        """Gets the executions of this OrmPipelineSpecEdges.  # noqa: E501


        :return: The executions of this OrmPipelineSpecEdges.  # noqa: E501
        :rtype: list[OrmPipelineExecution]
        """
        return self._executions

    @executions.setter
    def executions(self, executions):
        """Sets the executions of this OrmPipelineSpecEdges.


        :param executions: The executions of this OrmPipelineSpecEdges.  # noqa: E501
        :type executions: list[OrmPipelineExecution]
        """

        self._executions = executions

    @property
    def pipeline(self):
        """Gets the pipeline of this OrmPipelineSpecEdges.  # noqa: E501


        :return: The pipeline of this OrmPipelineSpecEdges.  # noqa: E501
        :rtype: OrmPipeline
        """
        return self._pipeline

    @pipeline.setter
    def pipeline(self, pipeline):
        """Sets the pipeline of this OrmPipelineSpecEdges.


        :param pipeline: The pipeline of this OrmPipelineSpecEdges.  # noqa: E501
        :type pipeline: OrmPipeline
        """

        self._pipeline = pipeline

    @property
    def pipeline_step_external_services(self):
        """Gets the pipeline_step_external_services of this OrmPipelineSpecEdges.  # noqa: E501


        :return: The pipeline_step_external_services of this OrmPipelineSpecEdges.  # noqa: E501
        :rtype: list[OrmPipelineStepExternalService]
        """
        return self._pipeline_step_external_services

    @pipeline_step_external_services.setter
    def pipeline_step_external_services(self, pipeline_step_external_services):
        """Sets the pipeline_step_external_services of this OrmPipelineSpecEdges.


        :param pipeline_step_external_services: The pipeline_step_external_services of this OrmPipelineSpecEdges.  # noqa: E501
        :type pipeline_step_external_services: list[OrmPipelineStepExternalService]
        """

        self._pipeline_step_external_services = pipeline_step_external_services

    @property
    def pipeline_step_ifs(self):
        """Gets the pipeline_step_ifs of this OrmPipelineSpecEdges.  # noqa: E501


        :return: The pipeline_step_ifs of this OrmPipelineSpecEdges.  # noqa: E501
        :rtype: list[OrmPipelineStepIf]
        """
        return self._pipeline_step_ifs

    @pipeline_step_ifs.setter
    def pipeline_step_ifs(self, pipeline_step_ifs):
        """Sets the pipeline_step_ifs of this OrmPipelineSpecEdges.


        :param pipeline_step_ifs: The pipeline_step_ifs of this OrmPipelineSpecEdges.  # noqa: E501
        :type pipeline_step_ifs: list[OrmPipelineStepIf]
        """

        self._pipeline_step_ifs = pipeline_step_ifs

    @property
    def pipeline_step_jupyter_visualizations(self):
        """Gets the pipeline_step_jupyter_visualizations of this OrmPipelineSpecEdges.  # noqa: E501


        :return: The pipeline_step_jupyter_visualizations of this OrmPipelineSpecEdges.  # noqa: E501
        :rtype: list[OrmPipelineStepJupyterVisualization]
        """
        return self._pipeline_step_jupyter_visualizations

    @pipeline_step_jupyter_visualizations.setter
    def pipeline_step_jupyter_visualizations(self, pipeline_step_jupyter_visualizations):
        """Sets the pipeline_step_jupyter_visualizations of this OrmPipelineSpecEdges.


        :param pipeline_step_jupyter_visualizations: The pipeline_step_jupyter_visualizations of this OrmPipelineSpecEdges.  # noqa: E501
        :type pipeline_step_jupyter_visualizations: list[OrmPipelineStepJupyterVisualization]
        """

        self._pipeline_step_jupyter_visualizations = pipeline_step_jupyter_visualizations

    @property
    def pipeline_step_manual_inputs(self):
        """Gets the pipeline_step_manual_inputs of this OrmPipelineSpecEdges.  # noqa: E501


        :return: The pipeline_step_manual_inputs of this OrmPipelineSpecEdges.  # noqa: E501
        :rtype: list[OrmPipelineStepManualInput]
        """
        return self._pipeline_step_manual_inputs

    @pipeline_step_manual_inputs.setter
    def pipeline_step_manual_inputs(self, pipeline_step_manual_inputs):
        """Sets the pipeline_step_manual_inputs of this OrmPipelineSpecEdges.


        :param pipeline_step_manual_inputs: The pipeline_step_manual_inputs of this OrmPipelineSpecEdges.  # noqa: E501
        :type pipeline_step_manual_inputs: list[OrmPipelineStepManualInput]
        """

        self._pipeline_step_manual_inputs = pipeline_step_manual_inputs

    @property
    def pipeline_step_manual_judgments(self):
        """Gets the pipeline_step_manual_judgments of this OrmPipelineSpecEdges.  # noqa: E501


        :return: The pipeline_step_manual_judgments of this OrmPipelineSpecEdges.  # noqa: E501
        :rtype: list[OrmPipelineStepManualJudgment]
        """
        return self._pipeline_step_manual_judgments

    @pipeline_step_manual_judgments.setter
    def pipeline_step_manual_judgments(self, pipeline_step_manual_judgments):
        """Sets the pipeline_step_manual_judgments of this OrmPipelineSpecEdges.


        :param pipeline_step_manual_judgments: The pipeline_step_manual_judgments of this OrmPipelineSpecEdges.  # noqa: E501
        :type pipeline_step_manual_judgments: list[OrmPipelineStepManualJudgment]
        """

        self._pipeline_step_manual_judgments = pipeline_step_manual_judgments

    @property
    def pipeline_step_runs(self):
        """Gets the pipeline_step_runs of this OrmPipelineSpecEdges.  # noqa: E501


        :return: The pipeline_step_runs of this OrmPipelineSpecEdges.  # noqa: E501
        :rtype: list[OrmPipelineStepRun]
        """
        return self._pipeline_step_runs

    @pipeline_step_runs.setter
    def pipeline_step_runs(self, pipeline_step_runs):
        """Sets the pipeline_step_runs of this OrmPipelineSpecEdges.


        :param pipeline_step_runs: The pipeline_step_runs of this OrmPipelineSpecEdges.  # noqa: E501
        :type pipeline_step_runs: list[OrmPipelineStepRun]
        """

        self._pipeline_step_runs = pipeline_step_runs

    @property
    def pipeline_step_specs(self):
        """Gets the pipeline_step_specs of this OrmPipelineSpecEdges.  # noqa: E501


        :return: The pipeline_step_specs of this OrmPipelineSpecEdges.  # noqa: E501
        :rtype: list[OrmPipelineStepSpec]
        """
        return self._pipeline_step_specs

    @pipeline_step_specs.setter
    def pipeline_step_specs(self, pipeline_step_specs):
        """Sets the pipeline_step_specs of this OrmPipelineSpecEdges.


        :param pipeline_step_specs: The pipeline_step_specs of this OrmPipelineSpecEdges.  # noqa: E501
        :type pipeline_step_specs: list[OrmPipelineStepSpec]
        """

        self._pipeline_step_specs = pipeline_step_specs

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmPipelineSpecEdges):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmPipelineSpecEdges):
            return True

        return self.to_dict() != other.to_dict()
